@@ -470,9 +470,9 @@ if __name__ == "__main__":
     # rs = oe.get_openEuler_everything_rpm2src("24.03-LTS-SP2", "x86_64")
     # print(len(rs.keys()))
 
-    # oe = OpenEuler()
-    # rs = oe.get_openEuler_epol_rpm2src("24.03-LTS-SP2", "x86_64")
-    # print(len(rs.keys()))
+    oe = OpenEuler()
+    rs = oe.get_openEuler_epol_rpm2src("24.03-LTS-SP2", "x86_64")
+    print(len(rs.keys()))
 
     pass
 
